==> pymovements-0.8.0-py3-none-any.whl: pymovements/utils/__init__.py <==
# Copyright (c) 2022-2023 The pymovements Project Authors
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""This module provides access to all utility functions.

.. rubric:: Modules

.. autosummary::
   :toctree:
   :template: module.rst

    pymovements.utils.archives
    pymovements.utils.checks
    pymovements.utils.decorators
    pymovements.utils.downloads
    pymovements.utils.filters
    pymovements.utils.parsing
    pymovements.utils.paths
"""
from pymovements.utils import archives  # noqa: F401
from pymovements.utils import checks  # noqa: F401
from pymovements.utils import decorators  # noqa: F401
from pymovements.utils import downloads  # noqa: F401
from pymovements.utils import parsing  # noqa: F401
from pymovements.utils import paths  # noqa: F401

==> pymovements-0.18.0-py3-none-any.whl: pymovements/utils/__init__.py <==
# Copyright (c) 2022-2024 The pymovements Project Authors
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Provides utility functions.

.. rubric:: Modules

.. autosummary::
   :toctree:
   :template: module.rst

    pymovements.utils.archives
    pymovements.utils.checks
    pymovements.utils.decorators
    pymovements.utils.downloads
    pymovements.utils.filters
    pymovements.utils.parsing
    pymovements.utils.paths
"""
from pymovements.utils import archives
from pymovements.utils import checks
from pymovements.utils import decorators
from pymovements.utils import downloads
from pymovements.utils import parsing
from pymovements.utils import paths


__all__ = [
    'archives',
    'checks',
    'decorators',
    'downloads',
    'parsing',
    'paths',
]
